summaryrefslogtreecommitdiffstats
path: root/src/gui/application/main.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-01-24 13:26:42 -0600
committerTimothy Pearson <[email protected]>2013-01-24 13:26:42 -0600
commit59ff04ffaf48f18383b39ea6da17b8e18b6b50c3 (patch)
tree3c5878d4255116c6146b38687214acf355eb7564 /src/gui/application/main.cpp
parentc329cc4e7edb85184878ba8238c4344cbaba2ac0 (diff)
downloadrosegarden-59ff04ffaf48f18383b39ea6da17b8e18b6b50c3.tar.gz
rosegarden-59ff04ffaf48f18383b39ea6da17b8e18b6b50c3.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'src/gui/application/main.cpp')
-rw-r--r--src/gui/application/main.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gui/application/main.cpp b/src/gui/application/main.cpp
index c1aac43..a4ddfdf 100644
--- a/src/gui/application/main.cpp
+++ b/src/gui/application/main.cpp
@@ -509,7 +509,7 @@ int main(int argc, char *argv[])
// If there is no config setting for the startup window size, set
// one now. But base the default on the appropriate desktop size
// (i.e. not the entire desktop, if Xinerama is in use). This is
// obtained from KGlobalSettings::desktopGeometry(), but we can't
// give it a meaningful point to measure from at this stage so we
// always use the "leftmost" display (point 0,0).
@@ -523,7 +523,7 @@ int main(int argc, char *argv[])
TQDesktopWidget *desktop = TDEApplication::desktop();
if (desktop) {
TQRect totalRect(desktop->screenGeometry());
- TQRect desktopRect = KGlobalSettings::desktopGeometry(TQPoint(0, 0));
+ TQRect desktopRect = TDEGlobalSettings::desktopGeometry(TQPoint(0, 0));
TQSize startupSize;
if (desktopRect.height() <= 800) {
startupSize = TQSize((desktopRect.width() * 6) / 7,
@@ -659,12 +659,12 @@ int main(int argc, char *argv[])
TQString soundFontPath = config->readEntry("soundfontpath", "");
TQFileInfo sfxLoadInfo(sfxLoadPath), soundFontInfo(soundFontPath);
if (sfxLoadInfo.isExecutable() && soundFontInfo.isReadable()) {
- KProcess* sfxLoadProcess = new KProcess;
+ TDEProcess* sfxLoadProcess = new TDEProcess;
(*sfxLoadProcess) << sfxLoadPath << soundFontPath;
RG_DEBUG << "Starting sfxload : " << sfxLoadPath << " " << soundFontPath << endl;
- TQObject::connect(sfxLoadProcess, TQT_SIGNAL(processExited(KProcess*)),
- &app, TQT_SLOT(sfxLoadExited(KProcess*)));
+ TQObject::connect(sfxLoadProcess, TQT_SIGNAL(processExited(TDEProcess*)),
+ &app, TQT_SLOT(sfxLoadExited(TDEProcess*)));
sfxLoadProcess->start();
} else {
@@ -509,7 +509,7 @@ int main(int argc, char *argv[])
// one now. But base the default on the appropriate desktop size
// (i.e. not the entire desktop, if Xinerama is in use). This is
- // obtained from KGlobalSettings::desktopGeometry(), but we can't
+ // obtained from TDEGlobalSettings::desktopGeometry(), but we can't
// give it a meaningful point to measure from at this stage so we
// always use the "leftmost" display (point 0,0).